==> ompl_1.5.2+ds1.orig.tar.xz: ompl-1.5.2/doc/markdown/developers.md <==
# Developers {#developers}

OMPL is developed and maintained by the [Kavraki Lab](http://kavrakilab.org) at Rice University, led by [Dr. Lydia Kavraki](https://www.cs.rice.edu/~kavraki). The development is coordinated by [Dr. Mark Moll](https://moll.ai), [Dr. Lydia Kavraki](https://www.cs.rice.edu/~kavraki) (Rice) and [Dr. Ioan Șucan](http://ioan.sucan.ro) (Waymo, formerly Rice). Many others have contributed to OMPL as well, as can be seen below.

## Contributors (in alphabetical order)

A breakdown of all contributions by commits can be found on GitHub for the [OMPL](https://github.com/ompl/ompl/graphs/contributors) and [OMPL.app](https://github.com/ompl/omplapp/graphs/contributors) repositories. Note that the number of commits or number of lines of code written by a contributor is a far from perfect indicator of the significance of a person's contributions. Indeed, some significant contributions like the initial RRT* implementation do not even show up on these pages, since this code predates the move to Github. Below is a manually curated list of people who have made significant contributions and the groups they were affiliated with at the time.

- [Jennifer Barry](http://people.csail.mit.edu/jbarry), Leslie Pack Kaelbling and Tomás Lozano-Pérez's [Learning in Intelligent Systems Group](http://lis.csail.mit.edu), MIT (now at Rethink Robotics)
- [Prudhvi Boyapalli](http://www.prudhviboyapalli.com), Rice University
- Leonard Bruns, Robert Bosch GmbH (now at KTH Royal Institute of Technology)
- Stephen Butler, Rice University
- Beck Chen, Rice University
- [Sachin Chitta](http://www.sachinchitta.org), SRI International (now at Boston Dynamics)
- [Ashley Clark](http://web.stanford.edu/group/arl/people/ashley-clark), Steve Rock's [Aerospace Robotics Lab](http://web.stanford.edu/group/arl), Stanford University
- [Dave Coleman](http://davetcoleman.com/),  Nikolaus Correll's [group](http://correll.cs.colorado.edu/), University of Colorado Boulder (now at [PickNik Robotics](https://picknik.ai))
- [Neil Dantam](http://www.neil.dantam.name), Rice University (now at Colorado School of Mines)
- [Andrew Dobson](http://www.pracsyslab.org/dobson), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.pracsyslab.org), Rutgers University
- Elizabeth Fudge, Rice University
- [Jonathan Gammell](https://robotic-esp.com/gammell/), Tim Barfoot's [Autonomous Space Robotics Lab](http://asrl.utias.utoronto.ca), University of Toronto (now professor at Oxford)
- Bryant Gipson, Rice University (now at Google)
- [Javier V Gomez](http://jvgomez.github.io), Universidad Carlos III de Madrid (now at Magic Leap)
- Florian Hauer, Georgia Tech
- Gil Jones, Google
- [Sertac Karaman](http://sertac.scripts.mit.edu/web), Emilio Frazzoli's [Aerospace Robotics and Embedded Systems Laboratory](http://ares.lids.mit.edu), MIT
- Henning Kayser, [PickNik Robotics](https://picknik.ai)
- [Zachary Kingston](http://zkingston.com), Rice University
- [Ryan Luna](http://www.ryanluna.com), Rice University (now at Waymo)
- Matt Maly, Rice University (now at Google)
- [James Marble](http://www.cse.unr.edu/robotics/pracsys/marble), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.cse.unr.edu/robotics/pracsys), University of Nevada, Reno
- Andreas Orthey, University of Stuttgart, Marc Toussaint's [Machine Learning & Robotics Lab](https://ipvs.informatik.uni-stuttgart.de/mlr/), University of Stuttgart
- Luigi Palmieri, Robert Bosch GmbH
- Scott Paulin, University of Canterbury, New Zealand
- [Alejandro Perez](http://people.csail.mit.edu/aperez/www), Seth Teller's [Robotics, Vision, and Sensor Networks Group](http://rvsn.csail.mit.edu), MIT
- [Oren Salzman](http://orensalzman.com), Dan Halperin's [Computational Geometry Lab](http://acg.cs.tau.ac.il), Tel Aviv University
- Edward Schmerling, Marco Pavone's [Autonomous Systems Lab](http://asl.stanford.edu), Stanford University
- Jonathan Sobieski, Rice University
- Marlin Strub, [Estimation, Search, and Planning group](https://robotic-esp.com) at Oxford
- Sonny Tarbouriech, University of Sherbrooke
- [Luis Torres](http://luis.web.unc.edu), Ron Alterovitz' [Computational Robotics Group](http://robotics.cs.unc.edu), University of North Carolina at Chapel Hill (now at Google)
- [Caleb Voss](http://calebvoss.com), Rice University (now at Georgia Tech)
- Bryce Willey, Rice University (now at [Realtime Robotics](https://rtr.ai))

==> ompl_1.6.0+ds1.orig.tar.xz: ompl-1.6.0/doc/markdown/developers.md <==
# Developers {#developers}

OMPL is developed and maintained by the [Kavraki Lab](http://kavrakilab.org) at Rice University, led by [Dr. Lydia Kavraki](https://www.cs.rice.edu/~kavraki). The development is coordinated by [Dr. Mark Moll](https://moll.ai), [Dr. Lydia Kavraki](https://www.cs.rice.edu/~kavraki) (Rice) and [Dr. Ioan Șucan](http://ioan.sucan.ro) (Waymo, formerly Rice). Many others have contributed to OMPL as well, as can be seen below.

## Contributors (in alphabetical order)

A breakdown of all contributions by commits can be found on GitHub for the [OMPL](https://github.com/ompl/ompl/graphs/contributors) and [OMPL.app](https://github.com/ompl/omplapp/graphs/contributors) repositories. Note that the number of commits or number of lines of code written by a contributor is a far from perfect indicator of the significance of a person's contributions. Indeed, some significant contributions like the initial RRT* implementation do not even show up on these pages, since this code predates the move to Github. Below is a manually curated list of people who have made significant contributions and the groups they were affiliated with at the time.

- [Jennifer Barry](http://people.csail.mit.edu/jbarry), Leslie Pack Kaelbling and Tomás Lozano-Pérez's [Learning in Intelligent Systems Group](http://lis.csail.mit.edu), MIT (now at Rethink Robotics)
- [Prudhvi Boyapalli](http://www.prudhviboyapalli.com), Rice University
- Leonard Bruns, Robert Bosch GmbH (now at KTH Royal Institute of Technology)
- Stephen Butler, Rice University
- Beck Chen, Rice University
- [Sachin Chitta](http://www.sachinchitta.org), SRI International (now at Boston Dynamics)
- [Ashley Clark](http://web.stanford.edu/group/arl/people/ashley-clark), Steve Rock's [Aerospace Robotics Lab](http://web.stanford.edu/group/arl), Stanford University
- [Dave Coleman](http://davetcoleman.com/),  Nikolaus Correll's [group](http://correll.cs.colorado.edu/), University of Colorado Boulder (now at [PickNik Robotics](https://picknik.ai))
- [Neil Dantam](http://www.neil.dantam.name), Rice University (now at Colorado School of Mines)
- [Andrew Dobson](http://www.pracsyslab.org/dobson), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.pracsyslab.org), Rutgers University
- Elizabeth Fudge, Rice University
- [Jonathan Gammell](https://robotic-esp.com/gammell/), Tim Barfoot's [Autonomous Space Robotics Lab](http://asrl.utias.utoronto.ca), University of Toronto (now professor at Oxford)
- Bryant Gipson, Rice University (now at Google)
- [Javier V Gomez](http://jvgomez.github.io), Universidad Carlos III de Madrid (now at Magic Leap)
- Florian Hauer, Georgia Tech
- Gil Jones, Google
- [Sertac Karaman](http://sertac.scripts.mit.edu/web), Emilio Frazzoli's [Aerospace Robotics and Embedded Systems Laboratory](http://ares.lids.mit.edu), MIT
- Henning Kayser, [PickNik Robotics](https://picknik.ai)
- [Zachary Kingston](http://zkingston.com), Rice University
- [Ryan Luna](http://www.ryanluna.com), Rice University (now at Waymo)
- Matt Maly, Rice University (now at Google)
- [James Marble](http://www.cse.unr.edu/robotics/pracsys/marble), Kostas Bekris' [Physics-aware Research for Autonomous Computational SYStems group](http://www.cse.unr.edu/robotics/pracsys), University of Nevada, Reno
- [Andreas Orthey](http://aorthey.de), Max-Planck Institute for Intelligent Systems, Marc Toussaint's [Intelligent & Learning Systems Lab](https://argmin.lis.tu-berlin.de/), Technical University of Berlin
- Luigi Palmieri, Robert Bosch GmbH
- Scott Paulin, University of Canterbury, New Zealand
- [Alejandro Perez](http://people.csail.mit.edu/aperez/www), Seth Teller's [Robotics, Vision, and Sensor Networks Group](http://rvsn.csail.mit.edu), MIT
- [Oren Salzman](http://orensalzman.com), Dan Halperin's [Computational Geometry Lab](http://acg.cs.tau.ac.il), Tel Aviv University
- Edward Schmerling, Marco Pavone's [Autonomous Systems Lab](http://asl.stanford.edu), Stanford University
- Jonathan Sobieski, Rice University
- Marlin Strub, [Estimation, Search, and Planning group](https://robotic-esp.com) at Oxford
- Sonny Tarbouriech, University of Sherbrooke
- [Luis Torres](http://luis.web.unc.edu), Ron Alterovitz' [Computational Robotics Group](http://robotics.cs.unc.edu), University of North Carolina at Chapel Hill (now at Google)
- [Caleb Voss](http://calebvoss.com), Rice University (now at Georgia Tech)
- Bryce Willey, Rice University (now at [Realtime Robotics](https://rtr.ai))
